==> rubocop_0.74.0%2Bdfsg.orig.tar.xz: rubocop-0.74.0/spec/rubocop/cop/lint/uri_regexp_spec.rb <==
# frozen_string_literal: true

RSpec.describe RuboCop::Cop::Lint::UriRegexp do
  subject(:cop) { described_class.new(config) }

  let(:config) { RuboCop::Config.new }

  it 'registers an offense when using `URI.regexp` with argument' do
    expect_offense(<<~RUBY)
      URI.regexp('http://example.com')
          ^^^^^^ `URI.regexp('http://example.com')` is obsolete and should not be used. Instead, use `URI::DEFAULT_PARSER.make_regexp('http://example.com')`.
    RUBY
  end

  it 'registers an offense when using `::URI.regexp` with argument' do
    expect_offense(<<~RUBY)
      ::URI.regexp('http://example.com')
            ^^^^^^ `::URI.regexp('http://example.com')` is obsolete and should not be used. Instead, use `::URI::DEFAULT_PARSER.make_regexp('http://example.com')`.
    RUBY
  end

  it 'registers an offense when using `URI.regexp` without argument' do
    expect_offense(<<~RUBY)
      URI.regexp
          ^^^^^^ `URI.regexp` is obsolete and should not be used. Instead, use `URI::DEFAULT_PARSER.make_regexp`.
    RUBY
  end

  it 'registers an offense when using `::URI.regexp` without argument' do
    expect_offense(<<~RUBY)
      ::URI.regexp
            ^^^^^^ `::URI.regexp` is obsolete and should not be used. Instead, use `::URI::DEFAULT_PARSER.make_regexp`.
    RUBY
  end

  it "autocorrects URI::DEFAULT_PARSER.make_regexp('http://example.com')" do
    new_source = autocorrect_source("URI.regexp('http://example.com')")

    expect(
      new_source
    ).to eq "URI::DEFAULT_PARSER.make_regexp('http://example.com')"
  end

  it "autocorrects ::URI::DEFAULT_PARSER.make_regexp('http://example.com')" do
    new_source = autocorrect_source("::URI.regexp('http://example.com')")

    expect(
      new_source
    ).to eq "::URI::DEFAULT_PARSER.make_regexp('http://example.com')"
  end

  it 'autocorrects URI::DEFAULT_PARSER.make_regexp' do
    new_source = autocorrect_source('URI.regexp')

    expect(new_source).to eq 'URI::DEFAULT_PARSER.make_regexp'
  end

  it 'autocorrects ::URI::DEFAULT_PARSER.make_regexp' do
    new_source = autocorrect_source('::URI.regexp')

    expect(new_source).to eq '::URI::DEFAULT_PARSER.make_regexp'
  end
end

==> rubocop_0.80.1%2Bdfsg.orig.tar.xz: rubocop-0.80.1/spec/rubocop/cop/lint/uri_regexp_spec.rb <==
# frozen_string_literal: true

RSpec.describe RuboCop::Cop::Lint::UriRegexp do
  subject(:cop) { described_class.new(config) }

  let(:config) { RuboCop::Config.new }

  it 'registers an offense and corrects using `URI.regexp` with argument' do
    expect_offense(<<~RUBY)
      URI.regexp('http://example.com')
          ^^^^^^ `URI.regexp('http://example.com')` is obsolete and should not be used. Instead, use `URI::DEFAULT_PARSER.make_regexp('http://example.com')`.
    RUBY

    expect_correction(<<~RUBY)
      URI::DEFAULT_PARSER.make_regexp('http://example.com')
    RUBY
  end

  it 'registers an offense and corrects using `::URI.regexp` with argument' do
    expect_offense(<<~RUBY)
      ::URI.regexp('http://example.com')
            ^^^^^^ `::URI.regexp('http://example.com')` is obsolete and should not be used. Instead, use `::URI::DEFAULT_PARSER.make_regexp('http://example.com')`.
    RUBY

    expect_correction(<<~RUBY)
      ::URI::DEFAULT_PARSER.make_regexp('http://example.com')
    RUBY
  end

  it 'registers an offense and corrects using `URI.regexp` without argument' do
    expect_offense(<<~RUBY)
      URI.regexp
          ^^^^^^ `URI.regexp` is obsolete and should not be used. Instead, use `URI::DEFAULT_PARSER.make_regexp`.
    RUBY

    expect_correction(<<~RUBY)
      URI::DEFAULT_PARSER.make_regexp
    RUBY
  end

  it 'registers an offense and corrects using `::URI.regexp` ' \
    'without argument' do
    expect_offense(<<~RUBY)
      ::URI.regexp
            ^^^^^^ `::URI.regexp` is obsolete and should not be used. Instead, use `::URI::DEFAULT_PARSER.make_regexp`.
    RUBY

    expect_correction(<<~RUBY)
      ::URI::DEFAULT_PARSER.make_regexp
    RUBY
  end
end
